@@ -6,6 +6,7 @@ import copy
 from colorama.ansi import code_to_chars
 from .enums import PLACE, POST_HINT
 from .difinition import DEFAULT_GET_POST_DELIMITER, DEFAULT_COOKIE_DELIMITER
+from .crypto import bytes_decode, str2bytes
 
 
 def check_keys(require_keys, request_keys):
@@ -22,6 +23,11 @@ def getattr_value(arr, key):
     return getattr(arr, key) if key in arr else ''
 
 
+def transform_bytes_str(s: str):
+    """将str型的bytes内容解码"""
+    return bytes_decode(str2bytes(s))
+
+
 def get_valid_filename(s):
     """
     Return the given string converted to a string that can be used for a clean filename.
@@ -385,14 +391,13 @@ def contain(s1, s2):
     return is_contain, row
 
 
-def randomStr(dig):
-    ''' 生产随机字符串 '''
-    strs = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz'
-    s = ''
-    for i in range(dig):
-        key = random.randint(0, len(strs) - 1)
-        s += strs[key]
-    return s
+def randomStr(dig=6):
+    """
+    生成随机字符串
+    :param dig: 几个字符
+    :return:
+    """
+    return ''.join(random.choices(string.ascii_lowercase + string.digits, k=k))
 
 
 def randomInt(start=0, end=10):
@@ -408,3 +413,26 @@ def clean(s):
     s = re.sub('^[^a-zA-Z_]+', '', s)
     if s.isnumeric(): s = '_' + s
     return s
+
+
+def compare_func2func(fun1, fun2, test_list=[], times=100, *arg, **kwarg):
+    import time
+    result = {}
+
+    a = time.time()
+    res1 = []
+    for i in range(times):
+        for example in test_list:
+            res1.append(fun1(example, *arg, **kwarg))
+    result['fun1_time'] = time.time() - a
+    result['fun1_res'] = res1
+
+    a = time.time()
+    res2 = []
+    for i in range(times):
+        for example in test_list:
+            res2.append(fun2(example, *arg, **kwarg))
+    result['fun2_time'] = time.time() - a
+    result['fun2_res'] = res2
+
+    return result
