@@ -22,14 +22,21 @@ def abs_cwd_base(path):
     return os.path.join(pwd, path)
 
 
+def abs_file():
+    """
+    获取调用此函数的文件的绝对路径
+    :return:
+    """
+    return traceback.extract_stack()[-2].filename
+
+
 def abs_file_base(path=''):
     """
     获取当前【调用此函数的文件的上级目录】为基准开始的某个路径的绝对路径
-    :param path: 请传入 __file__
+    :param path: 上级目录下的文件路径位置
     :return:
     """
-    file = traceback.extract_stack()[-2].filename
-    db_path = os.path.dirname(os.path.abspath(file))
+    db_path = os.path.dirname(os.path.abspath(abs_file()))
     return os.path.join(db_path, path)
 
 
